@@ -4,7 +4,8 @@ import drms
 
 
 @pytest.mark.parametrize(
-    'exception_class', [drms.DrmsError, drms.DrmsQueryError, drms.DrmsExportError, drms.DrmsOperationNotSupported],
+    "exception_class",
+    [drms.DrmsError, drms.DrmsQueryError, drms.DrmsExportError, drms.DrmsOperationNotSupported],
 )
 def test_exception_class(exception_class):
     with pytest.raises(RuntimeError):
