@@ -4,11 +4,11 @@ import pytest
 @pytest.mark.jsoc
 @pytest.mark.remote_data
 @pytest.mark.parametrize(
-    'series, pkeys, segments',
+    "series, pkeys, segments",
     [
-        ('hmi.v_45s', ['T_REC', 'CAMERA'], ['Dopplergram']),
-        ('hmi.m_720s', ['T_REC', 'CAMERA'], ['magnetogram']),
-        ('hmi.v_avg120', ['CarrRot', 'CMLon'], ['mean', 'power', 'valid', 'Log']),
+        ("hmi.v_45s", ["T_REC", "CAMERA"], ["Dopplergram"]),
+        ("hmi.m_720s", ["T_REC", "CAMERA"], ["magnetogram"]),
+        ("hmi.v_avg120", ["CarrRot", "CMLon"], ["mean", "power", "valid", "Log"]),
     ],
 )
 def test_series_info_basic(jsoc_client, series, pkeys, segments):
@@ -24,16 +24,16 @@ def test_series_info_basic(jsoc_client, series, pkeys, segments):
 @pytest.mark.jsoc
 @pytest.mark.remote_data
 @pytest.mark.parametrize(
-    'series, pkeys',
+    "series, pkeys",
     [
-        ('hmi.v_45s', ['T_REC', 'CAMERA']),
-        ('hmi.m_720s', ['T_REC', 'CAMERA']),
-        ('hmi.v_avg120', ['CarrRot', 'CMLon']),
-        ('aia.lev1', ['T_REC', 'FSN']),
-        ('aia.lev1_euv_12s', ['T_REC', 'WAVELNTH']),
-        ('aia.response', ['T_START', 'WAVE_STR']),
-        ('iris.lev1', ['T_OBS', 'FSN']),
-        ('mdi.fd_m_lev182', ['T_REC']),
+        ("hmi.v_45s", ["T_REC", "CAMERA"]),
+        ("hmi.m_720s", ["T_REC", "CAMERA"]),
+        ("hmi.v_avg120", ["CarrRot", "CMLon"]),
+        ("aia.lev1", ["T_REC", "FSN"]),
+        ("aia.lev1_euv_12s", ["T_REC", "WAVELNTH"]),
+        ("aia.response", ["T_START", "WAVE_STR"]),
+        ("iris.lev1", ["T_OBS", "FSN"]),
+        ("mdi.fd_m_lev182", ["T_REC"]),
     ],
 )
 def test_series_primekeys(jsoc_client, series, pkeys):
