@@ -9,12 +9,10 @@ try:
 except Exception:
     import warnings
 
-    warnings.warn(
-        f'could not determine {__name__.split(".")[0]} package version; this indicates a broken installation'
-    )
+    warnings.warn(f'could not determine {__name__.split(".")[0]} package version; this indicates a broken installation')
     del warnings
 
-    version = '0.0.0'
+    version = "0.0.0"
 
 
 # We use LooseVersion to define major, minor, micro, but ignore any suffixes.
@@ -37,4 +35,4 @@ major, minor, bugfix = split_version(version)
 
 del split_version  # clean up namespace.
 
-release = 'dev' not in version
+release = "dev" not in version
