@@ -25,15 +25,15 @@ email = os.environ["JSOC_EMAIL"]
 ###############################################################################
 # Construct the DRMS query string: "Series[timespan][wavelength]"
 
-qstr = 'hmi.ic_720s[2015.01.01_00:00:00_TAI/10d@1d]{continuum}'
+qstr = "hmi.ic_720s[2015.01.01_00:00:00_TAI/10d@1d]{continuum}"
 
 # Submit export request, defaults to method='url_quick' and protocol='as-is'
-print(f'Data export query:\n  {qstr}\n')
-print('Submitting export request...')
+print(f"Data export query:\n  {qstr}\n")
+print("Submitting export request...")
 result = client.export(qstr, email=email)
-print(f'len(r.urls) file(s) available for download.\n')
+print(f"len(r.urls) file(s) available for download.\n")
 
 # Print download URLs.
-for _, row in result.urls[['record', 'url']].iterrows():
-    print(f'REC: {row.record}')
-    print(f'URL: {row.url}\n')
+for _, row in result.urls[["record", "url"]].iterrows():
+    print(f"REC: {row.record}")
+    print(f"URL: {row.url}\n")
