@@ -20,21 +20,21 @@ client = drms.Client()
 ###############################################################################
 # Construct the DRMS query string: "Series[Carrington rotation]"
 
-qstr = 'hmi.synoptic_mr_720s[2150]'
+qstr = "hmi.synoptic_mr_720s[2150]"
 
 # Send request to the DRMS server
-print('Querying keyword data...\n -> {qstr}')
-segname = 'synopMr'
+print("Querying keyword data...\n -> {qstr}")
+segname = "synopMr"
 results, filenames = client.query(qstr, key=drms.const.all, seg=segname)
-print(f' -> {len(results)} lines retrieved.')
+print(f" -> {len(results)} lines retrieved.")
 
 # Use only the first line of the query result
 results = results.iloc[0]
-fname = f'http://jsoc.stanford.edu{filenames[segname][0]}'
+fname = f"http://jsoc.stanford.edu{filenames[segname][0]}"
 
 # Read the data segment
 # Note: HTTP downloads get cached in ~/.astropy/cache/downloads
-print(f'Reading data from {fname}...')
+print(f"Reading data from {fname}...")
 a = fits.getdata(fname)
 ny, nx = a.shape
 
@@ -64,13 +64,20 @@ aspect = abs((xmax - xmin) / nx * ny / (ymax - ymin))
 
 # Create plot
 fig, ax = plt.subplots(1, 1, figsize=(13.5, 6))
-ax.set_title(f'{qstr}, Time: {results.T_START} ... {results.T_STOP}', fontsize='medium')
+ax.set_title(f"{qstr}, Time: {results.T_START} ... {results.T_STOP}", fontsize="medium")
 ax.imshow(
-    a, vmin=-300, vmax=300, origin='lower', interpolation='nearest', cmap='gray', extent=extent, aspect=aspect,
+    a,
+    vmin=-300,
+    vmax=300,
+    origin="lower",
+    interpolation="nearest",
+    cmap="gray",
+    extent=extent,
+    aspect=aspect,
 )
 ax.invert_xaxis()
-ax.set_xlabel('Carrington longitude')
-ax.set_ylabel('Sine latitude')
+ax.set_xlabel("Carrington longitude")
+ax.set_ylabel("Sine latitude")
 fig.tight_layout()
 
 plt.show()
